# PyE3SM

PyE3SM is a Python library to assist E3SM model simulation.
Currently, it only supports the land and river components.


# Acknowledgement
This research was supported as part of the Next Generation Ecosystem Experiments-Tropics, funded by the U.S. Department of Energy, Office of Science, Office of Biological and Environmental Research at Pacific Northwest National Laboratory. The study was also partly supported by U.S. Department of Energy Office of Science Biological and Environmental Research through the Earth and Environmental System Modeling program as part of the Energy Exascale Earth System Model (E3SM) project. 

# Install
1. pip install pye3sm


# Contact
Please contact Chang Liao (chang.liao@pnnl.gov) if you have any questions.


